monkey.ci.containers.log-ingest

Event handlers that tail log files generated by build commands

Event handlers that tail log files generated by build commands
raw docstring

add-configclj

(add-config conf)
source

add-ingest-streamsclj

(add-ingest-streams ctx s)
source

command-endclj

(command-end ctx)
source

command-startclj

(command-start ctx)
source

get-configclj

source

get-ingest-streamsclj

source

get-local-dirclj

(get-local-dir ctx sid)
source

get-std-filesclj

source

get-stream-creatorclj

source

make-routesclj

(make-routes conf)

Creates Mailman routes to handle command events for log ingestion.

Creates Mailman routes to handle command events for log ingestion.
sourceraw docstring

remove-ingest-streamsclj

(remove-ingest-streams ctx s)
source

save-local-dirclj

Saves local run dir in state, because we'll need it to translate the paths in command events to actual directories.

Saves local run dir in state, because we'll need it to translate the paths in command events
to actual directories.
sourceraw docstring

set-configclj

(set-config ctx c)
source

set-local-dirclj

(set-local-dir ctx sid p)
source

set-stream-creatorclj

(set-stream-creator ctx sc)
source

start-ingestclj

source

stop-ingestclj

source

cljdoc builds & hosts documentation for Clojure/Script libraries