Functions for working with errors and exceptions. This provides a uniform way to handle exceptions and convert them into a usable format for internal propagation and to give useful feedback to the user.
Functions for working with errors and exceptions. This provides a uniform way to handle exceptions and convert them into a usable format for internal propagation and to give useful feedback to the user.
Convert argument into an application error
Convert argument into an application error
Creates a new application error with type and properties
Creates a new application error with type and properties
(unwrap-exception ex)Unwraps the exception to its cause, if any. If the exception contains a body, returns a new exception with the body converted into a string. This is useful when logging HTTP client errors.
Unwraps the exception to its cause, if any. If the exception contains a body, returns a new exception with the body converted into a string. This is useful when logging HTTP client errors.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |