monkey.ci.events.edn

Functionality for reading events from an edn reader. This is used in container jobs, where the script writes events about the commands to a shared file.

Functionality for reading events from an edn reader.  This is used in
container jobs, where the script writes events about the commands to
a shared file.
raw docstring

eof?clj

source

read-ednclj

(read-edn reader callback)

Reads lines from the given reader, and passes each of them as parsed edn to the callback fn. If the callback returns false or throws an error, the async process is terminated. On EOF, the callback is passed ::eof instead of a data map.

Reads lines from the given reader, and passes each of them as parsed edn 
to the callback fn.  If the callback returns `false` or throws an error, 
the async process is terminated.  On EOF, the callback is passed `::eof`
instead of a data map.
sourceraw docstring

(read-next r)
source

sleep-on-eofclj

(sleep-on-eof h interval)

Wraps the handler to sleep whenever eof is encountered

Wraps the handler to sleep whenever eof is encountered
sourceraw docstring

stop-at-eofclj

(stop-at-eof h)

Wraps the given callback to return false on ::eof

Wraps the given callback to return `false` on `::eof`
sourceraw docstring

stop-on-file-deleteclj

(stop-on-file-delete h f)

Wraps the handler but stops when eof is encountered and the given file has been deleted.

Wraps the handler but stops when eof is encountered and the given file has
been deleted.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries