Mailman-style event handling
Mailman-style event handling
(listener-stream m opts)Registers a listener that posts received events to a stream. Closing the stream unregisters the listener.
Registers a listener that posts received events to a stream. Closing the stream unregisters the listener.
(merge-routes & routes)Merges multiple route structures into one
Merges multiple route structures into one
(post-events mm events)Posts events using the broker in the mailman component
Posts events using the broker in the mailman component
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |