monkey.ci.events.mailman.interceptors

General purpose interceptors

General purpose interceptors
raw docstring

add-job-ctxclj

(add-job-ctx jc)
source

add-job-to-ctxclj

(add-job-to-ctx get-job)
source

add-mailmanclj

(add-mailman mm)

Adds mailman component to the context

Adds mailman component to the context
sourceraw docstring

add-timeclj

source

cancel-process-killclj

(cancel-process-kill ctx)

When a kill deferred is present in the context, cancels it. Otherwise noop.

When a kill deferred is present in the context, cancels it.  Otherwise noop.
sourceraw docstring

forwarderclj

(forwarder id dest)

Interceptor that forwards events to another broker

Interceptor that forwards events to another broker
sourceraw docstring

get-dbclj

source

get-job-ctxclj

source

get-mailmanclj

source

get-processclj

source

get-process-killclj

source

get-resultclj

source

get-stateclj

source

handle-build-errorclj

Marks build as failed

Marks build as failed
sourceraw docstring

handle-job-errorclj

source

no-resultclj

Empties result

Empties result
sourceraw docstring

realize-deferredclj

(realize-deferred d)
source

schedule-process-killclj

(schedule-process-kill timeout-fn)

When a process is stored in the context, schedules a kill in the period return by the timeout-fn, which takes the context as arg. Sets a deferred in the context that can be used to cancel the kill.

When a process is stored in the context, schedules a kill in the period
return by the `timeout-fn`, which takes the context as arg.  Sets a deferred
in the context that can be used to cancel the kill.
sourceraw docstring

set-dbclj

(set-db ctx db)
source

set-job-ctxclj

(set-job-ctx ctx jc)
source

set-mailmanclj

(set-mailman ctx e)
source

set-processclj

(set-process ctx ws)
source

set-process-killclj

(set-process-kill ctx p)
source

set-resultclj

(set-result ctx r)
source

set-stateclj

(set-state ctx q)
source

start-processclj

Starts a child process using the command line stored in the result

Starts a child process using the command line stored in the result
sourceraw docstring

terminate-whenclj

(terminate-when id pred)
source

trace-evtclj

Logs event info, for debugging purposes.

Logs event info, for debugging purposes.
sourceraw docstring

update-busclj

(update-bus bus)
source

update-job-ctxclj

(update-job-ctx ctx f & args)
source

update-stateclj

(update-state ctx f & args)
source

use-dbclj

(use-db db)

Adds storage to the context as ::db

Adds storage to the context as ::db
sourceraw docstring

with-stateclj

(with-state state)

Interceptor that keeps track of a global state object in the context. The updated state is deep-merged into the global state.

Interceptor that keeps track of a global state object in the context.
The updated state is `deep-merge`d into the global state.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries