Clojure only.

monkey.ci.local.console

Event handlers for console reporting

Event handlers for console reporting
raw docstring

Interceptor that prints the configured messages to the console.

Interceptor that prints the configured messages to the console.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries