monkey.ci.mailing.scw

Scaleway implementation of the Mailer, that uses transactional emails to send mails.

Scaleway implementation of the Mailer, that uses transactional emails to send mails.
raw docstring

No vars found in this namespace.

monkey.ci.mailing.template

Mail template functionality, for replacing values.

Mail template functionality, for replacing values.
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries