monkey.ci.metrics.entity-stats

Metrics that reflect some statistics on entities. These are typically lazy and execute a count query on retrieval.

Metrics that reflect some statistics on entities.  These are typically
lazy and execute a count query on retrieval.
raw docstring

monkey.ci.metrics.otlp

OpenTelemetry client implementation, used to push metrics to an OTLP collector endpoint (e.g. Scaleway cockpit).

OpenTelemetry client implementation, used to push metrics to an OTLP 
collector endpoint (e.g. Scaleway cockpit).
raw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries