monkey.ci.plans


calc-expiration-timeclj

(calc-expiration-time {p :valid-period} ts)
source

free-planclj

source

make-org-planclj

(make-org-plan org-id plan)

Creates a plan for the org, using the given plan template. If no template is given, creates a free plan.

Creates a plan for the org, using the given plan template.  If no template is
given, creates a free plan.
sourceraw docstring

plan->subclj

(plan->sub plan)

Creates a new subscription entity for the specified plan.

Creates a new subscription entity for the specified plan.
sourceraw docstring

sub->creditsclj

(sub->credits cs ts)

Creates a credits entity from given subscription using given timestamp to calculate valid times.

Creates a credits entity from given subscription using given timestamp to
calculate valid times.
sourceraw docstring

validate-plancljmultimethod

source

cljdoc builds & hosts documentation for Clojure/Script libraries