Accepted script extensions, in order of processing
Accepted script extensions, in order of processing
(load-jobs build rt)Loads the script and resolves the jobs
Loads the script and resolves the jobs
(resolve-jobs p rt)The build script must return something that satisfies JobResolvable.
This function resolves the jobs by processing the script return value
and assigns a generic id to the jobs that don't have one yet.
The build script must return something that satisfies `JobResolvable`. This function resolves the jobs by processing the script return value and assigns a generic id to the jobs that don't have one yet.
(verify dir)Verifies all scripts found in the directory. For clj, it runs a linter, for other types it tries to parse them. Returns verification results per file type.
Verifies all scripts found in the directory. For clj, it runs a linter, for other types it tries to parse them. Returns verification results per file type.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |