monkey.ci.utils


->base64clj

(->base64 s)
source

->seqclj

(->seq x)

Converts x into a sequential

Converts `x` into a sequential
sourceraw docstring

abs-pathclj

(abs-path p)
(abs-path a b)

If b is a relative path, will combine it with a, otherwise will just return b.

If `b` is a relative path, will combine it with `a`, otherwise
will just return `b`.
sourceraw docstring

abs-path-safeclj

(abs-path-safe a b)
source

add-shutdown-hook!clj

(add-shutdown-hook! h)

Executes h when the JVM shuts down. Returns the thread that will execute the hook.

Executes `h` when the JVM shuts down.  Returns the thread that will
execute the hook.
sourceraw docstring

combineclj

(combine a b)

Returns the canonical path of combining a and b

Returns the canonical path of combining `a` and `b`
sourceraw docstring

cwdclj

(cwd)

Returns current directory

Returns current directory
sourceraw docstring

delete-dirclj

(delete-dir dir)

Deletes directory recursively

Deletes directory recursively
sourceraw docstring

ensure-dir-exists!clj

(ensure-dir-exists! f)

If f is a file, ensures that the directory containing f exists.

If `f` is a file, ensures that the directory containing `f` exists.
sourceraw docstring

file-hashclj

(file-hash path)

Calculates md5 hash for given file

Calculates md5 hash for given file
sourceraw docstring

fn-nameclj

(fn-name x)

If x points to a fn, returns its name without namespace

If x points to a fn, returns its name without namespace
sourceraw docstring

get-all-ip-addressesclj

(get-all-ip-addresses)

Lists all non-loopback, non-virtual site local ip addresses

Lists all non-loopback, non-virtual site local ip addresses
sourceraw docstring

get-ip-addrclj

(get-ip-addr)

Determines the ip address of this VM by selecting the first of all available addresses. This could be an ipv4 or ipv6 address.

Determines the ip address of this VM by selecting the first of all available addresses.
This could be an ipv4 or ipv6 address.
sourceraw docstring

InetAddressStringcljprotocol

inetaddr->strclj

(inetaddr->str a)

Returns textual representation of the inet address

Returns textual representation of the inet address
source

load-privkeyclj

(load-privkey f)

Load private key from file or from string

Load private key from file or from string
sourceraw docstring

log-deferred-elapsedclj

(log-deferred-elapsed x msg)

Given a deferred, keeps track of time elapsed and logs it

Given a deferred, keeps track of time elapsed and logs it
sourceraw docstring

maybe-derefclj

(maybe-deref x)
source

mkdirs!clj

(mkdirs! f)
source

name->display-idclj

(name->display-id n existing?)

Generates a unique display id using the given name. It checks the existing? fn to avoid collisions.

Generates a unique display id using the given name.  It checks the `existing?`
fn to avoid collisions.
sourceraw docstring

nowclj

source

or-nilclj

(or-nil f)

Wraps f so that when the argument is nil, it also returns nil and does not invoke f.

Wraps `f` so that when the argument is `nil`, it also returns `nil` and does not invoke `f`.
sourceraw docstring

parse-ednclj

Parses edn from the reader

Parses edn from the reader
sourceraw docstring

parse-edn-strclj

(parse-edn-str s)
source

parse-sidcljdeprecated

source

prune-treeclj

(prune-tree t)
source

rebase-pathclj

(rebase-path p from to)

Given two absolute paths, recalculates p so that it becomes relative to to instead of from.

Given two absolute paths, recalculates p so that it becomes relative to `to` instead
of `from`.
sourceraw docstring

round-upclj

(round-up x)

Rounds the decimal argument up to the next integer value

Rounds the decimal argument up to the next integer value
sourceraw docstring

serialize-sidcljdeprecated

source

sid->repo-sidcljdeprecated

source

stack-traceclj

(stack-trace ex)

Prints stack trace to a string

Prints stack trace to a string
sourceraw docstring

tmp-dirclj

(tmp-dir)
source

tmp-fileclj

(tmp-file name)
(tmp-file prefix suffix)

Generates a new temporary path

Generates a new temporary path
sourceraw docstring

try-slurpclj

(try-slurp x)

Reads the file if it exists, or just returns x

Reads the file if it exists, or just returns x
sourceraw docstring

update-nthclj

(update-nth c idx f & args)
source

wait-for-fileclj

(wait-for-file f & opts)

Periodically checks if given file exists. Returns a deferred that holds the path if it exists.

Periodically checks if given file exists.  Returns a deferred that holds
the path if it exists.
sourceraw docstring

wait-untilclj

(wait-until p & {:keys [period] :or {period 100}})

Periodically invokes predicate p. Returns a deferred that realizes when p becomes truthy. Returns the first truthy return value of p.

Periodically invokes predicate `p`.  Returns a deferred that realizes when `p`
becomes truthy.  Returns the first truthy return value of `p`.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries