monkey.ci.web.api.email-reg

Email registrations for mailings

Email registrations for mailings
raw docstring

confirm-emailclj

(confirm-email req)
source

create-email-registrationclj

(create-email-registration req)

Custom creation endpoint that ensures emails are not registered twice.

Custom creation endpoint that ensures emails are not registered twice.
sourceraw docstring

delete-email-registrationclj

source

get-email-registrationclj

source

new-confirmation-codeclj

(new-confirmation-code)
source

unregister-emailclj

(unregister-email req)

Multipurpose unregistration handler, meant to allow people to easily unsubscribe from the mailing list. It accepts a subscription id, an email or a user id. If it's an email subscription, the record is deleted. If it's a user id or email, the user settings are updated to no longer receive mailings.

Multipurpose unregistration handler, meant to allow people to easily unsubscribe
from the mailing list.  It accepts a subscription id, an email or a user id.  If
it's an email subscription, the record is deleted.  If it's a user id or email,
the user settings are updated to no longer receive mailings.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries