Specific org api routes
Specific org api routes
(auto-subs)Automatically assigned subscriptions. These can be temporary actions as well.
Automatically assigned subscriptions. These can be temporary actions as well.
(credits req)Returns details of org credits
Returns details of org credits
(latest-builds req)Fetches the latest build for each repo for the org. This is used in the org overview screen.
Fetches the latest build for each repo for the org. This is used in the org overview screen.
(recent-builds req)Fetches all builds for the org that were executed in the past 24 hours, or since
a given query parameter. Or the last x builds. If both query parameters are provided,
it will do a logical and (meaning: the builds from the recent period, and the last
number of builds).
Fetches all builds for the org that were executed in the past 24 hours, or since a given query parameter. Or the last x builds. If both query parameters are provided, it will do a logical `and` (meaning: the builds from the recent period, and the last number of builds).
(stats req)Retrieves org statistics, since given time and grouped by specified zone offset (or UTC if none given). This combines both elapsed seconds and consumed credits over period stats.
Retrieves org statistics, since given time and grouped by specified zone offset (or UTC if none given). This combines both elapsed seconds and consumed credits over period stats.
(stats-build-results req)Statistics about build success and failure over period
Statistics about build success and failure over period
Consumed credits over period statistics
Consumed credits over period statistics
Elapsed build duration statistics
Elapsed build duration statistics
(stats-job-results req)Similar to build-result-stats but for jobs.
Similar to `build-result-stats` but for jobs.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |