monkey.ci.web.api.plan


cancel-planclj

(cancel-plan req)

Cancels the current org plan at the given time (or now) by setting the valid-until time of the current plan, if any, and creating a new free plan that starts at the same time. This is essentially the same as creating a new free plan.

Cancels the current org plan at the given time (or now) by setting the `valid-until`
time of the current plan, if any, and creating a new free plan that starts at the
same time.  This is essentially the same as creating a new free plan.
sourceraw docstring

create-planclj

(create-plan req)

Creates a new plan as specified in the request body. Cancels any previous plans. Also creates a new credit subscription and cancels the previous one.

Creates a new plan as specified in the request body.  Cancels any previous
plans.  Also creates a new credit subscription and cancels the previous one.
sourceraw docstring

get-currentclj

(get-current req)
source

org-historyclj

(org-history req)
source

cljdoc builds & hosts documentation for Clojure/Script libraries