Event handlers that tail log files generated by build commands
Event handlers that tail log files generated by build commands
(make-routes conf)Creates Mailman routes to handle command events for log ingestion.
Creates Mailman routes to handle command events for log ingestion.
Saves local run dir in state, because we'll need it to translate the paths in command events to actual directories.
Saves local run dir in state, because we'll need it to translate the paths in command events to actual directories.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |