Functionality for reading events from an edn reader. This is used in container jobs, where the script writes events about the commands to a shared file.
Functionality for reading events from an edn reader. This is used in container jobs, where the script writes events about the commands to a shared file.
(read-edn reader callback)Reads lines from the given reader, and passes each of them as parsed edn
to the callback fn. If the callback returns false or throws an error,
the async process is terminated. On EOF, the callback is passed ::eof
instead of a data map.
Reads lines from the given reader, and passes each of them as parsed edn to the callback fn. If the callback returns `false` or throws an error, the async process is terminated. On EOF, the callback is passed `::eof` instead of a data map.
(sleep-on-eof h interval)Wraps the handler to sleep whenever eof is encountered
Wraps the handler to sleep whenever eof is encountered
(stop-at-eof h)Wraps the given callback to return false on ::eof
Wraps the given callback to return `false` on `::eof`
(stop-on-file-delete h f)Wraps the handler but stops when eof is encountered and the given file has been deleted.
Wraps the handler but stops when eof is encountered and the given file has been deleted.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |