monkey.ci.logging.log-ingest

Client for log ingestion microservice

Client for log ingestion microservice
raw docstring

fetch-logsclj

(fetch-logs client path)

Retrieves any logs at specified path

Retrieves any logs at specified path
sourceraw docstring

make-clientclj

(make-client conf)
source

make-ingest-loggerclj

(make-ingest-logger client opts build path)
source

make-log-ingest-retrieverclj

(make-log-ingest-retriever client)
source

push-logsclj

(push-logs client path logs)

Pushes given logs at specified path

Pushes given logs at specified path
sourceraw docstring

pushing-streamclj

(pushing-stream client
                {:keys [path buf-size interval]
                 :or {buf-size 65536 interval 1000}})

Returns an OutputStream that pushes the received bytes to the log ingester at configured intervals, or after a given number of bytes.

Returns an `OutputStream` that pushes the received bytes to the log ingester
at configured intervals, or after a given number of bytes.
sourceraw docstring

stream-fileclj

(stream-file
  f
  s
  &
  [{:keys [interval buf-size] :or {interval 1000 buf-size 65536} :as opts}])

Reads the given logfile to the sink. When the sink is closed, or eof is reached, the streaming operation is stopped. Additional options can be specified to set buffer size and push interval. Returns a deferred that will hold the reason the async loop has stopped.

Reads the given logfile to the sink.  When the sink is closed, or eof is reached,
the streaming operation is stopped.  Additional options can be specified to set
buffer size and push interval.  Returns a deferred that will hold the reason the
async loop has stopped.
sourceraw docstring

stream-file-when-existsclj

(stream-file-when-exists f s & opts)

Waits until file f exists, then streams its contents to Manifold sink s. Returns a deferred that will hold the result of the streaming operation. In order to stop reading the file, close the sink.

Waits until file `f` exists, then streams its contents to Manifold sink `s`.
Returns a deferred that will hold the result of the streaming operation.
In order to stop reading the file, close the sink.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries