Client for log ingestion microservice
Client for log ingestion microservice
(fetch-logs client path)Retrieves any logs at specified path
Retrieves any logs at specified path
(push-logs client path logs)Pushes given logs at specified path
Pushes given logs at specified path
(pushing-stream client
{:keys [path buf-size interval]
:or {buf-size 65536 interval 1000}})Returns an OutputStream that pushes the received bytes to the log ingester
at configured intervals, or after a given number of bytes.
Returns an `OutputStream` that pushes the received bytes to the log ingester at configured intervals, or after a given number of bytes.
(stream-file
f
s
&
[{:keys [interval buf-size] :or {interval 1000 buf-size 65536} :as opts}])Reads the given logfile to the sink. When the sink is closed, or eof is reached, the streaming operation is stopped. Additional options can be specified to set buffer size and push interval. Returns a deferred that will hold the reason the async loop has stopped.
Reads the given logfile to the sink. When the sink is closed, or eof is reached, the streaming operation is stopped. Additional options can be specified to set buffer size and push interval. Returns a deferred that will hold the reason the async loop has stopped.
(stream-file-when-exists f s & opts)Waits until file f exists, then streams its contents to Manifold sink s.
Returns a deferred that will hold the result of the streaming operation.
In order to stop reading the file, close the sink.
Waits until file `f` exists, then streams its contents to Manifold sink `s`. Returns a deferred that will hold the result of the streaming operation. In order to stop reading the file, close the sink.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |