Event handlers for mailings. E.g. to send out confirmation mails.
Event handlers for mailings. E.g. to send out confirmation mails.
Scaleway implementation of the Mailer, that uses transactional emails to send mails.
Scaleway implementation of the Mailer, that uses transactional emails to send mails.
No vars found in this namespace.
Mail template functionality, for replacing values.
Mail template functionality, for replacing values.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |