(make-org-plan org-id plan)Creates a plan for the org, using the given plan template. If no template is given, creates a free plan.
Creates a plan for the org, using the given plan template. If no template is given, creates a free plan.
(plan->sub plan)Creates a new subscription entity for the specified plan.
Creates a new subscription entity for the specified plan.
(sub->credits cs ts)Creates a credits entity from given subscription using given timestamp to calculate valid times.
Creates a credits entity from given subscription using given timestamp to calculate valid times.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |