Email registrations for mailings
Email registrations for mailings
(create-email-registration req)Custom creation endpoint that ensures emails are not registered twice.
Custom creation endpoint that ensures emails are not registered twice.
(unregister-email req)Multipurpose unregistration handler, meant to allow people to easily unsubscribe from the mailing list. It accepts a subscription id, an email or a user id. If it's an email subscription, the record is deleted. If it's a user id or email, the user settings are updated to no longer receive mailings.
Multipurpose unregistration handler, meant to allow people to easily unsubscribe from the mailing list. It accepts a subscription id, an email or a user id. If it's an email subscription, the record is deleted. If it's a user id or email, the user settings are updated to no longer receive mailings.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |